################
Sphinx Bootstrap
################

RST roles for Bootstrap elements.

*******
Buttons
*******

+ **Primary Button** \:bs_btn_primary\:\`Text\`
+ **Success Button** \:bs_btn_success\:\`Text\`